@@ -41,7 +41,7 @@ import yarg
 ASSETS_URL = os.environ.get(
     'ASSETS_URL',
     'https://github.com/spyder-ide/windows-installer-assets/'
-    'releases/download/0.0.1/assets.zip')
+    'releases/latest/download/assets.zip')
 
 # Packages to remove from the requirements for example pip or
 # external direct dependencies (python-lsp-server spyder-kernels)
@@ -320,7 +320,7 @@ def unzip_file(filename, target_directory):
 
 def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
         license_path, extra_packages=None, conda_path=None, suffix=None,
-        template=None):
+        template=None, download_assets=True):
     """
     Run the installer generation.
 
@@ -329,12 +329,13 @@ def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
     (locking the dependencies set in setup.py) is generated and pynsist runned.
     """
     try:
-        print("Setting up assets from", ASSETS_URL)
-        print("Downloading assets from ", ASSETS_URL)
-        filename = download_file(ASSETS_URL, 'installers/Windows/assets')
+        if download_assets:
+            print("Setting up assets from", ASSETS_URL)
+            print("Downloading assets from ", ASSETS_URL)
+            filename = download_file(ASSETS_URL, 'installers/Windows/assets')
 
-        print("Unzipping assets to", 'installers/Windows/assets')
-        unzip_file(filename, 'installers/Windows/assets')
+            print("Unzipping assets to", 'installers/Windows/assets')
+            unzip_file(filename, 'installers/Windows/assets')
 
         with tempfile.TemporaryDirectory(
                 prefix="installer-pynsist-") as work_dir:
@@ -369,10 +370,16 @@ def run(python_version, bitness, repo_root, entrypoint, package, icon_path,
                 os.path.join(work_dir, "micromamba.exe"))
 
             print("Copying NSIS plugins into discoverable path")
-            shutil.copy(
-                "installers/Windows/assets/nsist/plugins/x86-unicode/"
-                "WinShell.dll",
-                "C:/Program Files (x86)/NSIS/Plugins/x86-unicode/WinShell.dll")
+            contents = os.listdir(
+                "installers/Windows/assets/nsist/plugins/x86-unicode/")
+            for element in contents:
+                shutil.copy(
+                    os.path.join(
+                        "installers/Windows/assets/nsist/plugins/x86-unicode/",
+                        element),
+                    os.path.join(
+                        "C:/Program Files (x86)/NSIS/Plugins/x86-unicode/",
+                        element))
 
             if template:
                 print("Copying template into discoverable path for Pynsist")
@@ -490,14 +497,27 @@ if __name__ == "__main__":
     parser.add_argument(
         '-t', '--template',
         help='Path to .nsi template for the installer')
+    parser.add_argument(
+        '-da', '--download_assets',
+        dest='download_assets', action='store_true',
+        help='Download assets from ASSETS_URL environment '''
+             '''variable when running''')
+    parser.add_argument(
+        '-no-da', '--no_download_assets',
+        dest='download_assets', action='store_false',
+        help='''Prevent downloading assets from ASSETS_URL environment '''
+             '''variable when running''')
+    parser.set_defaults(download_assets=True)
 
     args = parser.parse_args()
     from operator import attrgetter
     (python_version, bitness, setup_py_path, entrypoint, package, icon_path,
-     license_path, extra_packages, conda_path, suffix, template) = attrgetter(
+     license_path, extra_packages, conda_path, suffix, template,
+     download_assets) = attrgetter(
          'python_version', 'bitness', 'setup_py_path',
          'entrypoint', 'package', 'icon_path', 'license_path',
-         'extra_packages', 'conda_path', 'suffix', 'template')(args)
+         'extra_packages', 'conda_path', 'suffix', 'template',
+         'download_assets')(args)
 
     if not setup_py_path.endswith("setup.py"):
         sys.exit("Invalid path to setup.py:", setup_py_path)
@@ -512,4 +532,5 @@ if __name__ == "__main__":
 
     run(python_version, bitness, repo_root, entrypoint,
         package, icon_file, license_file, extra_packages=extra_packages,
-        conda_path=conda_path, suffix=suffix, template=template)
+        conda_path=conda_path, suffix=suffix, template=template,
+        download_assets=download_assets)
