@@ -15,29 +15,23 @@ import operator
 
 # Third party imports
 from qtpy.compat import to_qvariant
-from qtpy.QtCore import QDateTime, Qt, Signal, Slot
+from qtpy.QtCore import QDateTime, Qt, Signal
 from qtpy.QtWidgets import (QAbstractItemDelegate, QDateEdit, QDateTimeEdit,
                             QItemDelegate, QLineEdit, QMessageBox, QTableView)
+from spyder_kernels.utils.lazymodules import (
+    FakeObject, numpy as np, pandas as pd, PIL)
+from spyder_kernels.utils.nsview import (display_to_value, is_editable_type,
+                                         is_known_type)
 
 # Local imports
 from spyder.config.base import _, is_pynsist, running_in_mac_app
 from spyder.config.fonts import DEFAULT_SMALL_DELTA
 from spyder.config.gui import get_font
-from spyder_kernels.utils.nsview import (
-    array, DataFrame, Index, display_to_value, FakeObject,
-    Image, is_editable_type, is_known_type, MaskedArray, ndarray, Series)
 from spyder.py3compat import is_binary_string, is_text_string, to_text_string
+from spyder.plugins.variableexplorer.widgets.arrayeditor import ArrayEditor
+from spyder.plugins.variableexplorer.widgets.dataframeeditor import (
+    DataFrameEditor)
 from spyder.plugins.variableexplorer.widgets.texteditor import TextEditor
-from spyder.plugins.variableexplorer.widgets.objectexplorer.attribute_model \
-    import safe_tio_call
-
-if ndarray is not FakeObject:
-    from spyder.plugins.variableexplorer.widgets.arrayeditor import (
-            ArrayEditor)
-
-if DataFrame is not FakeObject:
-    from spyder.plugins.variableexplorer.widgets.dataframeeditor import (
-            DataFrameEditor)
 
 
 LARGE_COLLECTION = 1e5
@@ -46,8 +40,8 @@ LARGE_ARRAY = 5e6
 
 class CollectionsDelegate(QItemDelegate):
     """CollectionsEditor Item Delegate"""
-    sig_free_memory = Signal()
-    sig_open_editor = Signal()
+    sig_free_memory_requested = Signal()
+    sig_editor_creation_started = Signal()
     sig_editor_shown = Signal()
 
     def __init__(self, parent=None):
@@ -98,7 +92,7 @@ class CollectionsDelegate(QItemDelegate):
     def createEditor(self, parent, option, index, object_explorer=False):
         """Overriding method createEditor"""
         val_type = index.sibling(index.row(), 1).data()
-        self.sig_open_editor.emit()
+        self.sig_editor_creation_started.emit()
         if index.column() < 3:
             return None
         if self.show_warning(index):
@@ -108,6 +102,7 @@ class CollectionsDelegate(QItemDelegate):
                   "Do you want to continue anyway?"),
                 QMessageBox.Yes | QMessageBox.No)
             if answer == QMessageBox.No:
+                self.sig_editor_shown.emit()
                 return None
         try:
             value = self.get_value(index)
@@ -161,10 +156,16 @@ class CollectionsDelegate(QItemDelegate):
         key = index.model().get_key(index)
         readonly = (isinstance(value, (tuple, set)) or self.parent().readonly
                     or not is_known_type(value))
+
+        # We can't edit Numpy void objects because they could be anything, so
+        # this might cause a crash.
+        # Fixes spyder-ide/spyder#10603
+        if isinstance(value, np.void):
+            self.sig_editor_shown.emit()
+            return None
         # CollectionsEditor for a list, tuple, dict, etc.
-        if isinstance(value, (list, set, tuple, dict)) and not object_explorer:
-            from spyder.plugins.variableexplorer.widgets.collectionseditor \
-                import CollectionsEditor
+        elif isinstance(value, (list, set, tuple, dict)) and not object_explorer:
+            from spyder.widgets.collectionseditor import CollectionsEditor
             editor = CollectionsEditor(parent=parent)
             editor.setup(value, key, icon=self.parent().windowIcon(),
                          readonly=readonly)
@@ -172,8 +173,10 @@ class CollectionsDelegate(QItemDelegate):
                                             key=key, readonly=readonly))
             return None
         # ArrayEditor for a Numpy array
-        elif (isinstance(value, (ndarray, MaskedArray)) and
-                ndarray is not FakeObject and not object_explorer):
+        elif (isinstance(value, (np.ndarray, np.ma.MaskedArray)) and
+                np.ndarray is not FakeObject and not object_explorer):
+            # We need to leave this import here for tests to pass.
+            from .arrayeditor import ArrayEditor
             editor = ArrayEditor(parent=parent)
             if not editor.setup_and_check(value, title=key, readonly=readonly):
                 return
@@ -181,25 +184,32 @@ class CollectionsDelegate(QItemDelegate):
                                             key=key, readonly=readonly))
             return None
         # ArrayEditor for an images
-        elif (isinstance(value, Image) and ndarray is not FakeObject and
-                Image is not FakeObject and not object_explorer):
-            arr = array(value)
+        elif (isinstance(value, PIL.Image.Image) and
+                np.ndarray is not FakeObject and
+                PIL.Image is not FakeObject and
+                not object_explorer):
+            # Sometimes the ArrayEditor import above is not seen (don't know
+            # why), so we need to reimport it here.
+            # Fixes spyder-ide/spyder#16731
+            from .arrayeditor import ArrayEditor
+            arr = np.array(value)
             editor = ArrayEditor(parent=parent)
             if not editor.setup_and_check(arr, title=key, readonly=readonly):
                 return
-            conv_func = lambda arr: Image.fromarray(arr, mode=value.mode)
+            conv_func = lambda arr: PIL.Image.fromarray(arr, mode=value.mode)
             self.create_dialog(editor, dict(model=index.model(), editor=editor,
                                             key=key, readonly=readonly,
                                             conv=conv_func))
             return None
         # DataFrameEditor for a pandas dataframe, series or index
-        elif (isinstance(value, (DataFrame, Index, Series))
-                and DataFrame is not FakeObject and not object_explorer):
+        elif (isinstance(value, (pd.DataFrame, pd.Index, pd.Series))
+                and pd.DataFrame is not FakeObject and not object_explorer):
+            # We need to leave this import here for tests to pass.
+            from .dataframeeditor import DataFrameEditor
             editor = DataFrameEditor(parent=parent)
             if not editor.setup_and_check(value, title=key):
+                self.sig_editor_shown.emit()
                 return
-            editor.dataModel.set_format(index.model().dataframe_format)
-            editor.sig_option_changed.connect(self.change_option)
             self.create_dialog(editor, dict(model=index.model(), editor=editor,
                                             key=key, readonly=readonly))
             return None
@@ -252,26 +262,13 @@ class CollectionsDelegate(QItemDelegate):
                 return editor
         # ObjectExplorer for an arbitrary Python object
         else:
-            show_callable_attributes = index.model().show_callable_attributes
-            show_special_attributes = index.model().show_special_attributes
-            dataframe_format = index.model().dataframe_format
-
-            if show_callable_attributes is None:
-                show_callable_attributes = False
-            if show_special_attributes is None:
-                show_special_attributes = False
-
             from spyder.plugins.variableexplorer.widgets.objectexplorer \
                 import ObjectExplorer
             editor = ObjectExplorer(
                 value,
                 name=key,
                 parent=parent,
-                show_callable_attributes=show_callable_attributes,
-                show_special_attributes=show_special_attributes,
-                dataframe_format=dataframe_format,
                 readonly=readonly)
-            editor.sig_option_changed.connect(self.change_option)
             self.create_dialog(editor, dict(model=index.model(),
                                             editor=editor,
                                             key=key, readonly=readonly))
@@ -286,22 +283,6 @@ class CollectionsDelegate(QItemDelegate):
         self.sig_editor_shown.emit()
         editor.show()
 
-    @Slot(str, object)
-    def change_option(self, option_name, new_value):
-        """
-        Change configuration option.
-
-        This function is called when a `sig_option_changed` signal is received.
-        At the moment, this signal can only come from a DataFrameEditor
-        or an ObjectExplorer.
-        """
-        if option_name == 'dataframe_format':
-            self.parent().set_dataframe_format(new_value)
-        elif option_name == 'show_callable_attributes':
-            self.parent().toggle_show_callable_attributes(new_value)
-        elif option_name == 'show_special_attributes':
-            self.parent().toggle_show_special_attributes(new_value)
-
     def editor_accepted(self, editor_id):
         data = self._editors[editor_id]
         if not data['readonly']:
@@ -329,7 +310,7 @@ class CollectionsDelegate(QItemDelegate):
     def free_memory(self):
         """Free memory after closing an editor."""
         try:
-            self.sig_free_memory.emit()
+            self.sig_free_memory_requested.emit()
         except RuntimeError:
             pass
 
@@ -382,7 +363,6 @@ class CollectionsDelegate(QItemDelegate):
                                          self.get_value(index),
                                          ignore_errors=False)
             except Exception as msg:
-                raise
                 QMessageBox.critical(editor, _("Edit item"),
                                      _("<b>Unable to assign data to item.</b>"
                                        "<br><br>Error message:<br>%s"
@@ -485,8 +465,7 @@ class ToggleColumnDelegate(CollectionsDelegate):
 
         # CollectionsEditor for a list, tuple, dict, etc.
         if isinstance(value, (list, set, tuple, dict)):
-            from spyder.plugins.variableexplorer.widgets.collectionseditor \
-                import CollectionsEditor
+            from spyder.widgets.collectionseditor import CollectionsEditor
             editor = CollectionsEditor(parent=parent)
             editor.setup(value, key, icon=self.parent().windowIcon(),
                          readonly=readonly)
@@ -494,8 +473,8 @@ class ToggleColumnDelegate(CollectionsDelegate):
                                             key=key, readonly=readonly))
             return None
         # ArrayEditor for a Numpy array
-        elif (isinstance(value, (ndarray, MaskedArray)) and
-                ndarray is not FakeObject):
+        elif (isinstance(value, (np.ndarray, np.ma.MaskedArray)) and
+                np.ndarray is not FakeObject):
             editor = ArrayEditor(parent=parent)
             if not editor.setup_and_check(value, title=key, readonly=readonly):
                 return
@@ -503,25 +482,23 @@ class ToggleColumnDelegate(CollectionsDelegate):
                                             key=key, readonly=readonly))
             return None
         # ArrayEditor for an images
-        elif (isinstance(value, Image) and ndarray is not FakeObject and
-                Image is not FakeObject):
-            arr = array(value)
+        elif (isinstance(value, PIL.Image.Image) and
+                np.ndarray is not FakeObject and PIL.Image is not FakeObject):
+            arr = np.array(value)
             editor = ArrayEditor(parent=parent)
             if not editor.setup_and_check(arr, title=key, readonly=readonly):
                 return
-            conv_func = lambda arr: Image.fromarray(arr, mode=value.mode)
+            conv_func = lambda arr: PIL.Image.fromarray(arr, mode=value.mode)
             self.create_dialog(editor, dict(model=index.model(), editor=editor,
                                             key=key, readonly=readonly,
                                             conv=conv_func))
             return None
         # DataFrameEditor for a pandas dataframe, series or index
-        elif (isinstance(value, (DataFrame, Index, Series))
-                and DataFrame is not FakeObject):
+        elif (isinstance(value, (pd.DataFrame, pd.Index, pd.Series))
+                and pd.DataFrame is not FakeObject):
             editor = DataFrameEditor(parent=parent)
             if not editor.setup_and_check(value, title=key):
                 return
-            editor.dataModel.set_format(index.model().dataframe_format)
-            editor.sig_option_changed.connect(self.change_option)
             self.create_dialog(editor, dict(model=index.model(), editor=editor,
                                             key=key, readonly=readonly))
             return None
